@@ -122,11 +122,11 @@ the output will be username:password.
         command = f'adduser {u} --gecos "" --disabled-password'
         perform.execute(command, root=True, teach=args.teach, noop=args.noop)
         
-        command = f"pwgen 16 1"
+        command = f"pwgen -s -y 20 1"
         password = perform.execute(command, pipe=True, teach=args.teach, noop=args.noop)
         if password: password = password.readline().strip()
         
-        command = f'echo "{u}:{password}" | sudo chpasswd'
+        command = f'echo "{u}:{pasword}" | sudo chpasswd'
         perform.execute(command, root=True, teach=args.teach, noop=args.noop)
 
         print()
@@ -769,19 +769,20 @@ def orphans(args):
     util.requires_package("deborphan")
     perform.execute("deborphan", teach=args.teach, noop=args.noop)
 
+
 # PASSWORD
-    
+
 def password(args):
     """Generate a good password optionally with punctuation
 
 Default is to generate one password.
 
-Simple usage to generate a list of 5 passwords of length 20 with 
+Simple usage to generate a list of 5 passwords of length 20 with
 special characters (punctuation).:
 
   $ wajig password --punct 5 20
 """
-    length = args.length if args.length else 16
+    length = args.length if args.length else 20
     number = args.number if args.number else 1
     if args.punct:
         command = f"cat /dev/urandom | tr -cd '[:graph:]' | head -c {length}; echo"
@@ -791,7 +792,7 @@ special characters (punctuation).:
                 perform.execute(command)
     else:
         util.requires_package("pwgen")
-        command = f"pwgen {length} {number} | tr ' ' '\n'"
+        command = f"pwgen -s -y {length} {number} | tr ' ' '\n'"
         perform.execute(command, teach=args.teach, noop=args.noop)
 
 # POLICY
